Module apk

Module apk 

Modules

add_libs_into_apk
align_apk
gen_unaligned_apk
install_apk
sign_apk

Functions

add_libs_into_apk
Adds given lib and all reletad libs into APK. Uses readelf, aapt tools
align_apk
Aligns APK on 4-byte memory boundary. Uses zipalign build tools
find_library_path
Resolves native library using search paths
gen_unaligned_apk
Generates unaligned APK with given manifest_path, assets and res. Uses aapt build tool
get_libs_in_dir
Return all files in directory with .so ending
install_apk
Installs given APK in emulator or connected device. Runs adb install -r ... command
readelf_list_shared_libs
List all linked shared libraries
recursively_define_needed_libs
Update needed_libs hashset with given lib and all related libs. Note: libc++ is not a system lib. If you use libc++_shared.so, it must be included in your APK. https://developer.android.com/ndk/guides/cpp-support
search_dylibs
Search dylibs in given deps_dir
sign_apk
Signs APK with given key. Uses apksigner build tool