write_cmake_toolchain

Function write_cmake_toolchain 

pub fn write_cmake_toolchain(
    min_sdk_version: u32,
    ndk_path: &Path,
    build_target_dir: &Path,
    build_target: AndroidTarget,
) -> CargoResult<PathBuf>
Write a CMake toolchain which will remove references to the rustc build target before including the NDK provided toolchain. The NDK provided android toolchain will set the target appropriately Returns the path to the generated toolchain file