pub trait CommandExt {
// Required method
fn output_err(self, print_logs: bool) -> Result<Output>;
}Expand description
Extension trait for Command that helps
to wrap output and print logs from command execution.
Required Methods
Sourcefn output_err(self, print_logs: bool) -> Result<Output>
fn output_err(self, print_logs: bool) -> Result<Output>
Executes the command as a child process, then captures an output and return it. If command termination wasn’t successful wraps an output into error and return it.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".