Module types

Module types 

Re-exports

pub use android_manifest;
pub use apple_bundle;
pub use simctl;

Structs

Aapt2
AAPT2 (Android Asset Packaging Tool) is a build tool that Android Studio and Android Gradle Plugin use to compile and package your app’s resources. [AAPT2] parses, indexes, and compiles the resources into a binary format that is optimized for the Android platform
Aapt2Compile
Compile
Aapt2Convert
Converts an apk between binary and proto formats.
Aapt2Dump
Dump
Aapt2Link
Link
Aapt2Optimize
Preforms resource optimizations on an APK
AndroidNdk
Helper structure that contains information about the Android NDK Path and returns paths to the tools.
AndroidSdk
Helper structure that contains information about the Android SDK path and returns paths to the tools.
BuildApks
Generate a set of APKs from your app bundle
BuildBundle
Build your app bundle using bundletool
Bundletool
Bundletool
Config
Configuration information for crossbundle. This is not specific to a build, it is information relating to crossbundle itself.
ExtractApks
Extract device-specific APKs from an existing APK set
GetDeviceSpec
Generate and use device specification JSON files
GetSizeTotal
Measure the estimated download sizes of APKs in an APK set
InstallApks
Deploy APKs to a connected device
Shell
An abstraction around console output that remembers preferences for output verbosity and color.
VersionCode

Enums

AndroidStrategy
Supported strategies for building Android application.
AndroidTarget
Android Target.
AndroidToolsError
AppWrapper
Stands for what application wrapper to use on build.
ColorChoice
Whether messages should use color output
CrateType
IosStrategy
Supported strategies for building application for Apple devices.
IosTarget
iOS Target.
KeyPass
KsPass
OutputFormat
Profile
SubCommand
Target
TtyWidth
Verbosity
The requested verbosity of output.
Visibility

Traits

IntoRustTriple

Functions

aapt2_tool
Find aapt2 executable binary file in SDK and initialize it
android_sdk_path
Get path to android sdk
bundletool
Find bundletool jar file in home directory then set environment variable and initialize it
update_android_manifest_with_default
Updates AndroidManifest with default values.
update_info_plist_with_default
Updates InfoPlist with default values.