Re-exports
pub use android_manifest;pub use apple_bundle;pub use simctl;
Structs
- Aapt2
AAPT2(Android Asset Packaging Tool) is a build tool that Android Studio and Android Gradle Plugin use to compile and package your app’s resources. [AAPT2] parses, indexes, and compiles the resources into a binary format that is optimized for the Android platform- Aapt2
Compile - Compile
- Aapt2
Convert - Converts an apk between binary and proto formats.
- Aapt2
Dump - Dump
- Aapt2
Link - Link
- Aapt2
Optimize - Preforms resource optimizations on an APK
- Android
Ndk - Helper structure that contains information about the Android NDK Path and returns paths to the tools.
- Android
Sdk - Helper structure that contains information about the Android SDK path and returns paths to the tools.
- Build
Apks - Generate a set of APKs from your app bundle
- Build
Bundle - Build your app bundle using bundletool
- Bundletool
- Bundletool
- Config
- Configuration information for crossbundle. This is not specific to a build, it is information relating to crossbundle itself.
- Extract
Apks - Extract device-specific APKs from an existing APK set
- GetDevice
Spec - Generate and use device specification JSON files
- GetSize
Total - Measure the estimated download sizes of APKs in an APK set
- Install
Apks - Deploy APKs to a connected device
- Shell
- An abstraction around console output that remembers preferences for output verbosity and color.
- Version
Code
Enums
- Android
Strategy - Supported strategies for building Android application.
- Android
Target - Android Target.
- Android
Tools Error - AppWrapper
- Stands for what application wrapper to use on build.
- Color
Choice - Whether messages should use color output
- Crate
Type - IosStrategy
- Supported strategies for building application for Apple devices.
- IosTarget
- iOS Target.
- KeyPass
- KsPass
- Output
Format - Profile
- SubCommand
- Target
- TtyWidth
- Verbosity
- The requested verbosity of output.
- Visibility
Traits
Functions
- aapt2_
tool - Find aapt2 executable binary file in SDK and initialize it
- android_
sdk_ path - Get path to android sdk
- bundletool
- Find
bundletooljar file in home directory then set environment variable and initialize it - update_
android_ manifest_ with_ default - Updates
AndroidManifestwith default values. - update_
info_ plist_ with_ default - Updates
InfoPlistwith default values.